@@ -13,11 +13,13 @@
 ##############################################################################
 __doc__="""VerboseSecurity product.
 
-$Id: __init__.py,v 1.2 2002/08/30 15:21:39 shane Exp $
+$Id: __init__.py,v 1.3 2004/06/17 02:38:44 shane Exp $
 """
 
+import os
 from VerboseSecurityPolicy import VerboseSecurityPolicy
-from AccessControl.SecurityManager import setSecurityPolicy
-setSecurityPolicy(VerboseSecurityPolicy())
 
-import PermissionRolePatch
+if os.environ.get('ZOPE_VERBOSE_SECURITY', '1'):
+    from AccessControl.SecurityManager import setSecurityPolicy
+    setSecurityPolicy(VerboseSecurityPolicy())
+    import PermissionRolePatch
